@@ -37,18 +37,19 @@ ggobi_check_structs <- function() {
 
 .check_versions <- function() {
   versions <- c(
-    rggobi = sub("-.*", "", packageDescription("rggobi", fields = c("Version"))), 
+    rggobi = packageDescription("rggobi", fields = c("Version")), 
     ggobi  = ggobi_version()$"version string"
   )
+  # strip micro version and rev
+  versions <- sub("\\.[^.]*$", "", sub("-.*", "", versions))
   ver_comp <- compareVersion(versions["rggobi"], versions["ggobi"])
   if (ver_comp != 0) {
-    if (ver_comp > 0) versions <- rev(versions)
-    warning(
-      "Your ", names(versions)[1], " (", versions[1], ") ", 
-      "is newer than your ", names(versions)[2], " (", versions[2], "). ", 
-      "Please try to update your ", names(versions)[2], ".",
-      call.=FALSE
-    )
+    if (ver_comp < 0)
+      versions <- rev(versions)
+    warning("Your ", names(versions)[1], " (", versions[1],
+            ") is later than your ", names(versions)[2], " version (",
+            versions[2], "). Please try to update your ",
+            names(versions)[2], ".")
   }
   ver_comp == 0
 }
